#
# spec file for package python3-cffi
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-cffi
Version:        1.1.2
Release:        2.3
Summary:        Foreign Function Interface for Python calling C code
License:        MIT
Group:          Development/Languages/Python
Url:            http://cffi.readthedocs.org
Source0:        http://pypi.python.org/packages/source/c/cffi/cffi-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  pkgconfig(libffi)
# Documentation requirements:
BuildRequires:  python3-Sphinx
# Test requirements:
BuildRequires:  gcc-c++
BuildRequires:  python3-pycparser
BuildRequires:  python3-pytest
Requires:       python3-pycparser
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Foreign Function Interface for Python calling C code. The aim of this project
is to provide a convenient and reliable way of calling C code from Python.

%prep
%setup -q -n cffi-%{version}

%build
CFLAGS="%{optflags}" python3 setup.py build
python3 setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
PYTHONPATH=%{buildroot}%{python3_sitearch} py.test -x c testing

%files
%defattr(-,root,root,-)
%doc LICENSE build/sphinx/html/
%{python3_sitearch}/*

%changelog
* Mon Jun 15 2015 arun@gmx.de
- update to version 1.1.2:
  * ffi.gc(): fixed a race condition in multithreaded programs
    introduced in 1.1.1
- changes from version 1.1.1:
  * Out-of-line mode: ffi.string(), ffi.buffer() and ffi.getwinerror()
    didn't accept their arguments as keyword arguments, unlike their
    in-line mode equivalent. (It worked in PyPy.)
  * Out-of-line ABI mode: documented a restriction of ffi.dlopen()
    when compared to the in-line mode.
  * ffi.gc(): when called several times with equal pointers, it was
    accidentally registering only the last destructor, or even none at
    all depending on details. (It was correctly registering all of
    them only in PyPy, and only with the out-of-line FFIs.)
* Sun May 31 2015 arun@gmx.de
- update to version 1.1.0:
  * Out-of-line API mode: we can now declare integer types with
    typedef int... foo_t;. The exact size and signness of foo_t is
    figured out by the compiler.
  * Out-of-line API mode: we can now declare multidimensional arrays
    (as fields or as globals) with int n[...][...]. Before, only the
    outermost dimension would support the ... syntax.
  * Out-of-line ABI mode: we now support any constant declaration,
    instead of only integers whose value is given in the cdef. Such
    “new” constants, i.e. either non-integers or without a value given
    in the cdef, must correspond to actual symbols in the lib. At
    runtime they are looked up the first time we access them. This is
    useful if the library defines extern const sometype somename;.
  * ffi.addressof(lib, "func_name") now returns a regular cdata object
    of type “pointer to function”. You can use it on any function from
    a library in API mode (in ABI mode, all functions are already
    regular cdata objects). To support this, you need to recompile
    your cffi modules.
  * Issue #198: in API mode, if you declare constants of a struct
    type, what you saw from lib.CONSTANT was corrupted.
  * Issue #196: ffi.set_source("package._ffi", None) would incorrectly
    generate the Python source to package._ffi.py instead of
    package/_ffi.py. Also fixed: in some cases, if the C file was in
    build/foo.c, the .o file would be put in build/build/foo.o.
* Sat May 30 2015 arun@gmx.de
- specfile:
  * tests need c++ compiler
- update to version 1.0.3:
  * Same as 1.0.2, apart from doc and test fixes on some platforms.
- changes from version 1.0.2:
  * Variadic C functions (ending in a ”...” argument) were not
    supported in the out-of-line ABI mode. This was a bug—there was
    even a (non-working) example doing exactly that!
- changes from version 1.0.1:
  * ffi.set_source() crashed if passed a sources=[..] argument. Fixed
    by chrippa on pull request #60.
  * Issue #193: if we use a struct between the first cdef() where it
    is declared and another cdef() where its fields are defined, then
    this definition was ignored.
  * Enums were buggy if you used too many ”...” in their definition.
- changes from version 1.0.0:
  * The main news item is out-of-line module generation:
    + for ABI level, with ffi.dlopen()
    + for API level, which used to be with ffi.verify(), now deprecated
* Sat Mar 14 2015 arun@gmx.de
- update to version 0.9.2:
  * skip zintegration on win32, adjust zdistutils for setuptools
  * Test and fix for from_buffer() receiving read-only buffer objects
  * Py3 syntax
* Sun Mar  8 2015 arun@gmx.de
- update to version 0.9.1:
  * Add the MD5/SHA
  * gcc complains if given the obscure flag
    "-Werror=declaration-after-statement"
* Tue Mar  3 2015 arun@gmx.de
- specfile:
  * update copyright year
  * run test via py.test -c x testing
- update to version 0.9.0:
  * the types TBYTE TCHAR LPCTSTR PCTSTR LPTSTR PTSTR PTBYTE PTCHAR
    are no longer automatically defined; see ffi.set_unicode() below.
  * the other standard integer types from stdint.h, as long as they
    map to integers of 1, 2, 4 or 8 bytes. Larger integers are not
    supported.
  * You can give C++ source code in ffi.verify()
  * The optional flags argument has been added, see man dlopen
    (ignored on Windows). It defaults to ffi.RTLD_NOW.
  * The optional relative_to argument is useful if you need to list
    local files passed to the C compiler
  * You can give several field names in case of nested structures.
  * You can give several field names in case of nested structures, and
    you can give numeric values for array items.
* Thu Sep  4 2014 toddrme2178@gmail.com
- Fix typo in source line
* Wed Aug 27 2014 toddrme2178@gmail.com
- Re-enable unit tests
* Tue Aug 26 2014 toddrme2178@gmail.com
- Update to 0.8.6
  * No upstream changelog
    See https://bitbucket.org/cffi/cffi/commits/all for a list of
    commits
- update to 0.8.2
  * minor bugfixes
- remove cffi-pytest-integration.patch as it is no longer necessary
* Mon Feb 24 2014 mvyskocil@suse.com
- update to 0.8.1
  * fixes on Python 3 on OS/X, and some FreeBSD fixes (thanks Tobias)
  0.8:
  * integrated support for C99 variable-sized structures
  * multi-thread safety
  * ffi.getwinerror()
  * a number of small fixes
- added a note wrt disabled tests
- add cffi-pytest-integration.patch: allowinf call pytest from setup.py
* Tue Oct  1 2013 mvyskocil@suse.com
- Use python3-setuptools instead of distribute
* Mon Sep 30 2013 mvyskocil@suse.com
- port to python3
- use pkgconfig(libffi) to get the most recent ffi
* Mon Aug 19 2013 mvyskocil@suse.com
- Update to 0.7.2
  * add implicit bool
  * standard names are handled as defaults in cdef declarations
  * enum types follow GCC rules and not just int
  * supports simple slices x[start:stop]
  * enums are handled like ints
  * new ffi.new_handle(python_object)
  * and various bugfixes
* Sun Feb 10 2013 saschpe@suse.de
- Initial version
